<?php

namespace Drupal\Tests\eme\Functional;

use Drupal\Core\Extension\ModuleInstallerInterface;
use Drupal\eme\Eme;

/**
 * Tests EME and Drush compatibility – verifies usage steps in README.
 *
 * @group eme
 */
class DrushOperationsTest extends DrushTestBase {

  /**
   * Test export with Drush.
   */
  public function testExportDrush() {
    $this->config(Eme::CONFIG_NAME)
      ->set('module_machine', static::TEST_MODULE_NAME)
      ->set('migration_group', static::TEST_GROUP)
      ->set('migration_prefix', static::TEST_PREFIX)
      ->save();

    $this->createTestContent();

    // Let's export the test content.
    $this->drush('eme:export', [], [
      'types' => 'node,comment,user',
    ]);

    $module_installer = \Drupal::service('module_installer');
    assert($module_installer instanceof ModuleInstallerInterface);

    $module_installer->install([static::TEST_MODULE_NAME]);

    $exp_group_descr = static::TEST_GROUP . " (" . static::TEST_GROUP . ")";
    $ex_group_dashes = str_repeat('-', strlen($exp_group_descr));
    $exp_group_label = 'Group' . str_repeat(' ', strlen($exp_group_descr) - 5);

    $this->drush('migrate:status', [], [
      'group' => static::TEST_GROUP,
    ]);
    $this->assertEquals(
      <<<EOT
-{$ex_group_dashes}- --------------------- -------- ------- ---------- ------------- --------------- 
  {$exp_group_label}   Migration ID          Status   Total   Imported   Unprocessed   Last Imported  
 -{$ex_group_dashes}- --------------------- -------- ------- ---------- ------------- --------------- 
  {$exp_group_descr}   emi_user              Idle     4       0          4                            
  {$exp_group_descr}   emi_node_page         Idle     1       0          1                            
  {$exp_group_descr}   emi_node_article      Idle     2       0          2                            
  {$exp_group_descr}   emi_comment_article   Idle     2       0          2                            
 --------------------- --------------------- -------- ------- ---------- ------------- ---------------
EOT,
      $this->getOutput()
    );

    // Let's export only comments and their dependent entities.
    $this->drush('eme:export', [], [
      'types' => 'comment',
    ]);
    // Clear caches.
    $this->resetAll();

    $this->drush('migrate:status', [], [
      'group' => static::TEST_GROUP,
    ]);
    $this->assertEquals(
      <<<EOT
-{$ex_group_dashes}- --------------------- -------- ------- ---------- ------------- --------------- 
  {$exp_group_label}   Migration ID          Status   Total   Imported   Unprocessed   Last Imported  
 -{$ex_group_dashes}- --------------------- -------- ------- ---------- ------------- --------------- 
  {$exp_group_descr}   emi_user              Idle     2       0          2                            
  {$exp_group_descr}   emi_node_article      Idle     1       0          1                            
  {$exp_group_descr}   emi_comment_article   Idle     2       0          2                            
 --------------------- --------------------- -------- ------- ---------- ------------- ---------------
EOT,
      $this->getOutput()
    );

    // Delete the test content.
    $this->deleteTestContent();
    $this->assertEmpty(\Drupal::entityTypeManager()->getStorage('node')->loadMultiple());
    $expected_user_ids = [
      // Anonymous user.
      0 => 0,
      // Root user.
      1 => 1,
    ];
    $this->assertEquals($expected_user_ids, array_keys(\Drupal::entityTypeManager()->getStorage('user')->loadMultiple()));

    // Let's import the test content.
    $this->drush('migrate:import', ['--execute-dependencies'], [
      'group' => static::TEST_GROUP,
    ]);
    $this->assertTestContent();
  }

}
