<?php

namespace Drupal\Tests\eme\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\eme\Traits\EmeTestTrait;
use Drush\TestTraits\DrushTestTrait;
use org\bovigo\vfs\vfsStream;
use Symfony\Component\Filesystem\Filesystem;

/**
 * Base class for testing Drush integration.
 */
abstract class DrushTestBase extends BrowserTestBase {

  use DrushTestTrait;
  use EmeTestTrait;

  /**
   * The machine name of the test module in the tests.
   *
   * @const string
   */
  const TEST_MODULE_NAME = 'emetest';

  /**
   * The migration group of the generated migration plugins.
   *
   * @const string
   */
  const TEST_GROUP = 'emegroup';

  /**
   * The migration plugin ID prefix of the generated migration plugins.
   *
   * @const string
   */
  const TEST_PREFIX = 'emi';

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'filter',
    'text',
    'comment',
    'eme',
    'migrate_tools',
  ];

  /**
   * Sets up the root application path.
   */
  protected function setUpAppRoot(): void {
    if ($this->root === NULL) {
      $vfs_root = vfsStream::setup('emetest');
      vfsStream::copyFromFileSystem(DRUPAL_ROOT, $vfs_root);
      vfsStream::create([
        'modules' => [
          'custom' => [],
        ],
      ], $vfs_root);
      $this->root = 'vfs://emetest';
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function tearDown() {
    // Removes the test import module which was copied to the modules/custom
    // directory.
    if (file_exists(DRUPAL_ROOT . '/modules/custom/' . self::TEST_MODULE_NAME)) {
      (new Filesystem())->remove(DRUPAL_ROOT . '/modules/custom/' . self::TEST_MODULE_NAME);
    }
    parent::tearDown();
  }

}
